<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.UI.Xaml.Automation.Peers

Windows Runtime (WinRT) APIs for for the `Windows.UI.Xaml.Automation.Peers` namespace.

This package provides the `winrt.windows.ui.xaml.automation.peers` module.
